/*
 * Name:    mt_relay.c
 *
 * Purpose: Tcl interface to generic MX relay functions.
 *
 * Author:  William Lavender
 *
 *---------------------------------------------------------------------------
 *
 * Copyright 2001-2002, 2004 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#include <stdio.h>

#include <tcl.h>

#include "mx_util.h"
#include "mx_record.h"
#include "mx_relay.h"
#include "mx_handle.h"
#include "mx_tcl.h"
#include "mx_tcl_private.h"

MX_EXPORT int
Mx_relay_command_cmd( ClientData clientData, Tcl_Interp *interp,
			int objc, Tcl_Obj *CONST objv[] )
{
	static const char fname[] = "Mx_relay_command_cmd()";

	MX_RECORD *record;
	int relay_command, tcl_status;
	mx_status_type mx_status;

	if ( objc != 3 ) {
		Tcl_WrongNumArgs( interp, 2, objv,
		"Usage: relay_command record_handle value" );
		return TCL_ERROR;
	}

	mx_status = mxtcl_get_record_from_object( &record, interp, objv[1] );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	tcl_status = Tcl_GetIntFromObj( interp, objv[2], &relay_command );

	if ( tcl_status != TCL_OK )
		return mxtcl_object_parse_error(
				interp, objv[2], "integer", fname );

	/* Send the relay command. */

	mx_status = mx_relay_command( record, relay_command );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	return TCL_OK;
}

MX_EXPORT int
Mx_get_relay_status_cmd( ClientData clientData, Tcl_Interp *interp,
			int objc, Tcl_Obj *CONST objv[] )
{
	Tcl_Obj *resultPtr;
	MX_RECORD *record;
	int relay_status;
	mx_status_type mx_status;

	if ( objc != 2 ) {
		Tcl_WrongNumArgs( interp, 1, objv,
		"Usage: get_relay_status record_handle" );
		return TCL_ERROR;
	}

	mx_status = mxtcl_get_record_from_object( &record, interp, objv[1] );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	mx_status = mx_get_relay_status( record, &relay_status );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	resultPtr = Tcl_GetObjResult( interp );
	Tcl_SetIntObj( resultPtr, relay_status );

	return TCL_OK;
}

